==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/cmxpconsole.cpp <==
//
// C++ Implementation: cmxpconsole
//
// Description: 
//
//
// Author: Tomas Mecir <kmuddy@kmuddy.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//

#include "cmxpconsole.h"

#ifdef HAVE_MXP

#include "csession.h"
#include "dialogs/dlgmxpconsole.h"

#include <kapp.h>

cMXPConsole *cMXPConsole::_self = 0;

cMXPConsole::cMXPConsole ()
{
  dlgmxpconsole = 0;
}

cMXPConsole::~cMXPConsole ()
{
  delete dlgmxpconsole;
  dlgmxpconsole = 0;
}

cMXPConsole *cMXPConsole::self ()
{
  if (!_self)
    _self = new cMXPConsole;
  return _self;
}

void cMXPConsole::show ()
{
  if (!dlgmxpconsole)
    createDialog ();

  dlgmxpconsole->show ();
}

void cMXPConsole::hide ()
{
  if (!dlgmxpconsole)
    return;  //certainly not shown ;)

  dlgmxpconsole->hide ();
}

bool cMXPConsole::isVisible ()
{
  if (!dlgmxpconsole)
    return false;

  return dlgmxpconsole->isVisible ();
}

void cMXPConsole::createDialog ()
{
  if (!dlgmxpconsole)
  {
    dlgmxpconsole = new dlgMXPConsole ((KApplication::kApplication())->mainWidget());
    dlgmxpconsole->hide();  //just in case...
    connect (dlgmxpconsole, SIGNAL (finished ()), this, SIGNAL (finished()));
  }
}

#endif  //HAVE_MXP

//slots - these need to exist even if HAVE_MXP is off

void cMXPConsole::addError (cSession *sess, const QString &text)
{
#ifdef HAVE_MXP
  
  if (!dlgmxpconsole)
    createDialog ();

  dlgmxpconsole->addLine ("[ error ] (" + sess->name() + ") " + text);
  
#endif  //HAVE_MXP  
}

void cMXPConsole::addWarning (cSession *sess, const QString &text)
{
#ifdef HAVE_MXP
  
  if (!dlgmxpconsole)
    createDialog ();

  dlgmxpconsole->addLine ("[ warning ] (" + sess->name() + ") " + text);
  
#endif  //HAVE_MXP  
}


#include "cmxpconsole.moc"

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/cmxpconsole.cpp <==
//
// C++ Implementation: cmxpconsole
//
// Description: 
//
//
// Author: Tomas Mecir <kmuddy@kmuddy.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//

#include "cmxpconsole.h"

#ifdef HAVE_MXP

#include "cactionmanager.h"
#include "dialogs/dlgmxpconsole.h"

#include <kapp.h>

cMXPConsole *cMXPConsole::_self = 0;

cMXPConsole::cMXPConsole ()
{
  dlgmxpconsole = 0;
}

cMXPConsole::~cMXPConsole ()
{
  delete dlgmxpconsole;
  dlgmxpconsole = 0;
}

cMXPConsole *cMXPConsole::self ()
{
  if (!_self)
    _self = new cMXPConsole;
  return _self;
}

void cMXPConsole::show ()
{
  if (!dlgmxpconsole)
    createDialog ();

  dlgmxpconsole->show ();
}

void cMXPConsole::hide ()
{
  if (!dlgmxpconsole)
    return;  //certainly not shown ;)

  dlgmxpconsole->hide ();
}

bool cMXPConsole::isVisible ()
{
  if (!dlgmxpconsole)
    return false;

  return dlgmxpconsole->isVisible ();
}

void cMXPConsole::createDialog ()
{
  if (!dlgmxpconsole)
  {
    dlgmxpconsole = new dlgMXPConsole ((KApplication::kApplication())->mainWidget());
    dlgmxpconsole->hide();  //just in case...
    connect (dlgmxpconsole, SIGNAL (finished ()), this, SIGNAL (finished()));
  }
}

#endif  //HAVE_MXP

//slots - these need to exist even if HAVE_MXP is off

void cMXPConsole::addError (int sess, const QString &text)
{
#ifdef HAVE_MXP
  
  if (!dlgmxpconsole)
    createDialog ();

  QString name = cActionManager::self()->callAction ("session", "name", sess);
  dlgmxpconsole->addLine ("[ error ] (" + name + ") " + text);
  
#endif  //HAVE_MXP  
}

void cMXPConsole::addWarning (int sess, const QString &text)
{
#ifdef HAVE_MXP
  
  if (!dlgmxpconsole)
    createDialog ();

  QString name = cActionManager::self()->callAction ("session", "name", sess);
  dlgmxpconsole->addLine ("[ warning ] (" + name + ") " + text);
  
#endif  //HAVE_MXP  
}


#include "cmxpconsole.moc"
